

var TaskLayer = cc.Layer.extend({

    _task_list : null,
    _active_tab : 1,
    _bg : null,
    _width : 720,
    _height : 1160,
    _state : 0,

    ctor: function () {
        this._super();
        this.init();

        this.scheduleUpdate();
    },

    refresh: function(){
        this._task_list.removeAllItems();

        // for test
        var randCount = parseInt(Math.random() * 10 + 1);
        for(var i = 0; i < randCount; i ++) {

            var defaultItemLayout = new ccui.Layout();
            defaultItemLayout.setTouchEnabled(true);
            defaultItemLayout.setContentSize(this._width - 10, 153);
            defaultItemLayout.setTag(i + 1);

            var item = new TaskItem();
            item.setAnchorPoint(0.5, 0.5);
            item.setPosition(defaultItemLayout.width * 0.5, defaultItemLayout.height * 0.5);
            defaultItemLayout.addChild(item);
            this._task_list.pushBackCustomItem(defaultItemLayout);

        }

        this._task_list.jumpToTop(); // 跳到listview的顶部

        this._state = 0; // 还原_state
    },

    update: function(dt) {

        var inner_height = this._task_list.getInnerContainer().getContentSize().height;
        var outer_height = this._task_list.getContentSize().height;
        var inner_y = this._task_list.getInnerContainer().getPosition().y;
        var delta_y = inner_y - outer_height + inner_height;

        switch(this._state) {
            case 0: // 下拉刷新
                if (delta_y < -100) { // 向下位移超过100
                    this._state = 1;
                }
                break;
            case 1: // 松开刷新
                if (-0.001 < delta_y && delta_y < 0.001) { // 回到原始位置
                    this._state = 2;
                    this.refresh(); // 该函数结束时需要将_state还原为0
                }
                break;
            case 2: // 正在刷新
                break;
            default:
                break;
        }

    },

    init: function () {
        var that = this;

        // 添加弹窗整体背景
        this._bg = new ccui.ImageView(res.CommonDialogBg_png);
        this._bg.setScale9Enabled(true);
        this._bg.setPosition(cc.winSize.width / 2, cc.winSize.height / 2);
        this._bg.setContentSize(this._width, this._height);
        this.addChild(this._bg);

        // 添加背景表头
        var bgTitle = new ccui.ImageView(res.DialogTitle2_png);
        bgTitle.setScale(1.1);
        bgTitle.setPosition(this._width / 2, this._height);
        this._bg.addChild(bgTitle);

        var titleText = new ccui.ImageView(res.Task_word_renwu_png);
        titleText.setPosition(bgTitle.width / 2, bgTitle.height / 2 + 20);
        bgTitle.addChild(titleText);

        // 添加关闭按钮
        var close = new ccui.Button(res.RedClose_png, res.RedClose_png);
        close.setAnchorPoint(1, 1);
        close.setContentSize(90, 90);
        close.setPosition(this._width, this._height);
        close.addClickEventListener(function(){
            cc.log("close");
        });
        this._bg.addChild(close);

        // 添加TAB标签栏背景
        var top = new ccui.ImageView(res.Task_top_back_png);
        top.setAnchorPoint(0.5, 1);
        top.setPosition(this._width / 2, this._height - 70);
        this._bg.addChild(top);

        // 添加TAB标签栏内容
        var tab1 = new ccui.Button(res.Task_tab1_png, res.Task_tab1_png);
        tab1.setPosition(top.getContentSize().width / 2 - 200, top.getContentSize().height / 2);
        tab1.addClickEventListener(function(){
            that.switchToTab(1);
        });
        top.addChild(tab1);

        var tab_title1 = new cc.LabelTTF("活动", "Arial", 28);
        tab_title1.setPosition(tab1.getContentSize().width / 2, 20);
        tab1.addChild(tab_title1);

        var tab2 = new ccui.Button(res.Task_tab2_png, res.Task_tab2_png);
        tab2.setPosition(top.getContentSize().width / 2, top.getContentSize().height / 2);
        tab2.addClickEventListener(function(){
            that.switchToTab(2);
        });
        top.addChild(tab2);

        var tab_title2 = new cc.LabelTTF("奖励", "Arial", 28);
        tab_title2.setPosition(tab2.getContentSize().width / 2, 20);
        tab2.addChild(tab_title2);

        var tab3 = new ccui.Button(res.Task_tab3_png, res.Task_tab3_png);
        tab3.setPosition(top.getContentSize().width / 2 + 200, top.getContentSize().height / 2);
        tab3.addClickEventListener(function(){
            that.switchToTab(3);
        });
        top.addChild(tab3);

        var tab_title3 = new cc.LabelTTF("任务", "Arial", 28);
        tab_title3.setPosition(tab3.getContentSize().width / 2, 20);
        tab3.addChild(tab_title3);

        this.switchToTab(this._active_tab);
       
    },

    switchToTab: function (tabId) {

        if (this._task_list != null) {
            this._task_list.removeFromParent();
        }

        // 添加任务列表
        this._task_list = new ccui.ListView();
        this._task_list.setDirection(ccui.ScrollView.DIR_VERTICAL);
        this._task_list.setTouchEnabled(true);
        this._task_list.setBounceEnabled(true);
        this._task_list.setAnchorPoint(0.5, 1);
        this._task_list.setPosition(this._width / 2, this._height - 270);
        this._task_list.setContentSize(cc.size(this._width - 10, 880));

        // set size = 3 * tabId for test
        for(var i = 0; i < 3 * tabId; i ++) {

            var defaultItemLayout = new ccui.Layout();
            defaultItemLayout.setTouchEnabled(true);
            defaultItemLayout.setContentSize(this._width - 10, 153);
            defaultItemLayout.setTag(i + 1);

            var item = new TaskItem();
            item.setAnchorPoint(0.5, 0.5);
            item.setPosition(defaultItemLayout.width * 0.5, defaultItemLayout.height * 0.5);
            defaultItemLayout.addChild(item);
            this._task_list.pushBackCustomItem(defaultItemLayout);

        }

        this._bg.addChild(this._task_list);

        this._active_tab = tabId;

    },

});

var TaskScene = cc.Scene.extend({

    onEnter: function () {
        this._super();

        var taskLayer = new TaskLayer();
        this.addChild(taskLayer);
    }

});


